import React from "react";
import { View, Text, TextInput, Button } from "react-native";
import { style } from "../util/style";
import { createPost, NewPost, submitLogin } from "../util/api";

/**
 * NewPostContainer component for handling new post creation.
 *
 * @component
 * @param {object} props - React component props.
 * @param {object} props.navigation - Navigation object for navigating between screens.
 * @returns {JSX.Element} - Rendered NewPostContainer component.
 */
export function NewPostContainer({ navigation }): JSX.Element {
  /**
   * State hook for managing the current input text.
   * @type {[string, React.Dispatch<React.SetStateAction<string>>]}
   */
  const [currentInput, setCurrentInput] = React.useState<string>("");

  /**
   * State hook for managing the current input error message.
   * @type {[string, React.Dispatch<React.SetStateAction<string>>]}
   */
  const [currentInputError, setCurrentInputError] = React.useState<string>("");

  return (
    <View style={style.newPostContainer}>
      {/* Input field for the new post */}
      <TextInput
        style={style.newPostInput}
        placeholder="New Post"
        onChangeText={(text) => {
          setCurrentInput(text);
          setCurrentInputError("");
        }}
        value={currentInput}
      />

      {/* Button to submit the new post */}
      <Button
        title="Post"
        onPress={() => {
          /**
           * Asynchronously submits the new post.
           *
           * @async
           * @function
           * @returns {Promise<void>} - A Promise that resolves when the post is successfully submitted.
           */
          async function submit(): Promise<void> {
            // Submit login to obtain user token
            const user = (await submitLogin("demouser", "demopw")) ?? {
              token: "",
            };

            // Create new post object
            const newPost: NewPost = {
              content: currentInput,
              token: user.token,
            };

            // Call API to create the post
            await createPost(newPost);

            // Reset the input field
            setCurrentInput("");
          }

          // Check if the input is not empty before submitting
          if (currentInput.length > 0) {
            submit();
            // Navigate to the Home screen after successful post submission
            navigation.navigate("Home");
          } else {
            // Set an error message if the input is empty
            setCurrentInputError("Post must not be empty!");
          }
        }}
      />

      {/* Display error message if there's any */}
      <Text style={style.errorText}>{currentInputError}</Text>
    </View>
  );
}
